==> ToolChain_STM32_1.0.38.tar.bz: ToolChain_STM32_1.0.38/ToolChain/install_25_ADC.sh <==
#!/bin/bash

#
#  Install script for Fixpoint Mathematical Library 
#  URL: http://code.google.com/p/fixpointlib/
#
#  Script written by Gregor Rebel 2010-2011.
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition x86
# KUbuntu 11.04 x86
# openSuSE 11.4 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="500_ttc_adc"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------

  Name="${INSTALLPATH}" #{
  File="../extensions/makefile.${Name}" 
  createExtensionMakefileHead ${Name} #{
  cat <<END_OF_MAKEFILE >>$File 
# Adds Libraries/stm32_ADC.* to project.
# Provides helper function for using the Analog Digital Converters of CortexM3
# See Libraries/stm32_ADC.* for details!

  # activate certain parts of source-code
  COMPILE_OPTS += -DEXTENSION_${Name}
  
  INCLUDE_DIRS += -I additionals/common/
  vpath %.c additionals/common/
  
  MAIN_OBJS += stm32_adc.o

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}
  File="../extensions/activate.${Name}.sh" #{
  createActivateScriptHead $File $0 "architecture independent support of Analog Digital Converters (ToDo: INCOMPLETE)" 
  
  # create links into extensions.active/
  cat <<END_OF_ACTIVATE >>$File
  
createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET

activate.250_stm_std_peripherals__adc.sh QUIET

END_OF_ACTIVATE
  
  createActivateScriptTail $File $Name
  #}

#}

  echo "Installed successfully: $INSTALLPATH"

cd ..
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0

==> ToolChain_STM32_1.0.45.tar.bz: ToolChain_STM32_1.0.45/ToolChain/install_25_ADC.sh <==
#!/bin/bash

#
#  Install script for Fixpoint Mathematical Library 
#  URL: http://code.google.com/p/fixpointlib/
#
#  Script written by Gregor Rebel 2010-2011.
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition x86
# KUbuntu 11.04 x86
# openSuSE 11.4 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="500_ttc_adc"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------

  Name="${INSTALLPATH}" #{
  File="../extensions/makefile.${Name}" 
  createExtensionMakefileHead ${Name} #{
  cat <<END_OF_MAKEFILE >>$File 
# Adds Libraries/stm32_ADC.* to project.
# Provides helper function for using the Analog Digital Converters of CortexM3
# See Libraries/stm32_ADC.* for details!

  # activate certain parts of source-code
  COMPILE_OPTS += -DEXTENSION_${Name}
  
  INCLUDE_DIRS += -I additionals/common/
  vpath %.c additionals/common/
  
  MAIN_OBJS += stm32_adc.o

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}
  File="../extensions/activate.${Name}.sh" #{
  createActivateScriptHead $File $0 "architecture independent support of Analog Digital Converters (ToDo: INCOMPLETE)" 
  
  # create links into extensions.active/
  cat <<END_OF_ACTIVATE >>$File
  
createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET

activate.250_stm_std_peripherals__adc.sh QUIET \"\$0\"

END_OF_ACTIVATE
  
  createActivateScriptTail $File $Name
  #}

#}

  echo "Installed successfully: $INSTALLPATH"

cd ..
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0
